==> tdm_2.0.0.tar.gz: tdm/R/all.Amidihinfusionss.R <==
all.Amidihinfusionss<-function(){
     cat("\n")                                                                        
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Theinfusionss_input()
     cat("-----------------------------------------------------------------------\n")                                                            
     cat("\n")
     note_for_close_window()
     AmidihinfusionSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","R (hr)","ts (hr)","c (mg/L)"),value=c(0))                                                                                                          
     AmidihinfusionSSpar<-edit(AmidihinfusionSSpar)                                                                                                                                                                                                              
     AmidihinfusionSSpar<-ycheck(AmidihinfusionSSpar)     
     cat("\n")                                                                                                                                                                                                        
     Amidihinfusion.ss(AmidihinfusionSSpar[10,2],AmidihinfusionSSpar[9,2],AmidihinfusionSSpar[6,2],AmidihinfusionSSpar[3,2],AmidihinfusionSSpar[2,2],AmidihinfusionSSpar[5,2],AmidihinfusionSSpar[1,2],AmidihinfusionSSpar[4,2],AmidihinfusionSSpar[6,2],AmidihinfusionSSpar[8,2],AmidihinfusionSSpar[9,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Theinfusionss_output()
     cat("-----------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-Theinfusioncpr(0.8,AmidihinfusionSSpar[6,2],AmidihinfusionSSpar[8,2],AmidihinfusionSSpar[9,2],AmidihinfusionSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cm_pr (mg/L)")   
     coutput1<-coutput  
     show(coutput)
     C<-0.8*AmidihinfusionSSpar[8,2]/(samplesStats("cl"))
     sim<-matrix(C[1,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)") 
     coutput2<-coutput
     cat("\n")   
     Amidihinfusion.more()                         
}

==> tdm_2.2.6.tar.gz: tdm/R/all.Amidihinfusionss.R <==
all.Amidihinfusionss<-function(){
     cat("\n")                                                                        
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Theinfusionss_input()
     cat("-----------------------------------------------------------------------\n")                                                            
     cat("\n")
     note_for_close_window()
     AmidihinfusionSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","R (hr)","ts (hr)","c (mg/L)"),value=c(0))                                                                                                          
     AmidihinfusionSSpar<-edit(AmidihinfusionSSpar)                                                                                                                                                                                                              
##     AmidihinfusionSSpar<-ycheck(AmidihinfusionSSpar)     
     cat("\n")                                                                                                                                                                                                        
     Amidihinfusion.ss(AmidihinfusionSSpar[10,2],AmidihinfusionSSpar[9,2],AmidihinfusionSSpar[6,2],AmidihinfusionSSpar[3,2],AmidihinfusionSSpar[2,2],AmidihinfusionSSpar[5,2],AmidihinfusionSSpar[1,2],AmidihinfusionSSpar[4,2],AmidihinfusionSSpar[6,2],AmidihinfusionSSpar[8,2],AmidihinfusionSSpar[9,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Theinfusionss_output()
     cat("-----------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-Theinfusioncpr(0.8,AmidihinfusionSSpar[6,2],AmidihinfusionSSpar[8,2],AmidihinfusionSSpar[9,2],AmidihinfusionSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cm_pr (mg/L)")   
     coutput1<-coutput  
     show(coutput)
     C<-0.8*AmidihinfusionSSpar[8,2]/(samplesStats("cl"))
     sim<-matrix(C[1,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)") 
     coutput2<-coutput
     cat("\n")   
     Amidihinfusion.more()                         
}
